@@ -3,14 +3,13 @@ import sys
 
 import psutil
 
-from monk.pytorch_prototype import prototype
+from monk.keras_prototype import prototype
 from monk.compare_prototype import compare
 from monk.pip_unit_tests.keras.common import print_start
 from monk.pip_unit_tests.keras.common import print_status
 
 import torch
 import numpy as np
-from pytorch.losses.return_loss import load_loss
 
 
 def test_block_resnet_v1(system_dict):
