@@ -3,7 +3,7 @@ import sys
 
 import psutil
 
-from monk.gluon_prototype import prototype
+from monk.keras_prototype import prototype
 from monk.compare_prototype import compare
 from monk.pip_unit_tests.keras.common import print_start
 from monk.pip_unit_tests.keras.common import print_status
